@@ -20,7 +20,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK   = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT      = qw();
 
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 
 # Preloaded methods go here.
 
@@ -84,6 +84,62 @@ sub HTML::Element::content_handler {
 
 }
 
+
+sub make_counter {
+  my $i = 1;
+  sub {
+    shift() . ':' . $i++
+  }
+}
+
+
+sub HTML::Element::iter {
+  my ($tree, $p, @data) = @_;
+
+  #  warn 'P: ' , $p->attr('id') ;
+  #  warn 'H: ' , $p->as_HTML;
+
+  my $id_incr = make_counter;
+  my @item = map {
+    my $new_item = clone $p;
+    $new_item->replace_content($_);
+    $new_item->attr('id', $id_incr->( $p->attr('id') ));
+    $new_item;
+  } @data;
+
+  $p->replace_with(@item);
+
+}
+
+
+sub HTML::Element::dual_iter {
+  my ($parent, $data) = @_;
+
+  my ($prototype_a, $prototype_b) = $parent->content_list;
+
+  my $id_incr = make_counter;
+
+  my $i;
+
+  @$data %2 == 0 or 
+    confess 'dataset does not contain an even number of members';
+
+  my @iterable_data = reform (2, @$data);
+
+  my @item = map {
+    my ($new_a, $new_b) = map { clone $_ } ($prototype_a, $prototype_b) ;
+    $new_a->splice_content(0,1, $_->[0]);
+    $new_b->splice_content(0,1, $_->[1]);
+    $_->attr('id', $id_incr->($_->attr('id'))) for ($new_a, $new_b) ;
+    ($new_a, $new_b)
+  } @iterable_data;
+
+  $parent->delete_content;
+  $parent->push_content(@item);
+
+}
+
+
 sub HTML::Element::set_child_content {
   my $tree      = shift;
   my $content   = pop;
@@ -139,6 +195,7 @@ sub HTML::Element::highlander {
 
   warn "new tree: " . $tree->as_HTML if $DEBUG;
 
+  $survivor_node;
 }
 
 
@@ -148,6 +205,10 @@ sub HTML::Element::table {
 
   my $table = {};
 
+#  use Data::Dumper; warn Dumper \%table;
+
+  ++$DEBUG if $table{debug} ;
+
   $table->{table_node} = $s->look_down(id => $table{gi_table});
   $table->{table_node} or confess
     "table tag not found via (id => $table{gi_table}";
@@ -164,7 +225,7 @@ sub HTML::Element::table {
 #  tie my $iter_node, 'Tie::Cycle', \@iter_node;
   my $iter_node =  List::Rotation::Cycle->new(@iter_node);
 
-  warn $iter_node;
+#  warn $iter_node;
 
   warn Dumper ($iter_node, \@iter_node) if $DEBUG;
 
@@ -172,16 +233,14 @@ sub HTML::Element::table {
   $table->{parent}     = $table->{table_node}->parent;
 
 
-  $table->{table_node}->detach;
-  $_->detach for @iter_node;
+#  $table->{table_node}->detach;
+#  $_->detach for @iter_node;
 
-  my $add_table;
+  my @table_rows;
 
   while (my $row = $table{tr_data}->($table, $table{table_data})) 
     {
-      ++$add_table;
 
-      warn "add_table: $add_table" if $DEBUG;
 
 
       # wont work:      my $new_iter_node = $table->{iter_node}->clone;
@@ -191,10 +250,21 @@ sub HTML::Element::table {
 
 
       $table{td_data}->($new_iter_node, $row);
-      $table->{table_node}->push_content($new_iter_node);
+      push @table_rows, $new_iter_node;
     }
 
-  $table->{parent}->push_content($table->{table_node}) if $add_table;
+  if (@table_rows) {
+
+    my $replace_with_elem = $s->look_down(id => shift @table_gi_tr) ;
+    for (@table_gi_tr) {
+      $s->look_down(id => $_)->detach;
+    }
+
+    $replace_with_elem->replace_with(@table_rows);
+
+  }
+
+
 
 }
 
@@ -215,7 +285,7 @@ sub HTML::Element::unroll_select {
 
   while (my $row = $select{data_iter}->($select{data}))
     {
-      warn Dumper($row);
+#      warn Dumper($row);
       my $o = $option->clone;
       $o->attr('value', $select{option_value}->($row));
       $o->attr('SELECTED', 1) if ($select{option_selected}->($row)) ;
@@ -465,7 +535,7 @@ available here is discussed.
  </html>
 
 
-=head4 The manual way (not recommended)
+=head4 The manual way (*NOT* recommended)
 
  require 'simple-class.pl';
  use HTML::Seamstress;
